import os
import sys
import time

def clear_line():
  _, columns = os.popen('stty size', 'r').read().split()
  width = int(columns) - 2
  sys.stdout.write('\r')
  for i in range(1, width):
    sys.stdout.write(' ')
  sys.stdout.write('\r')
  sys.stdout.flush()

def progress_bar(pmax, val, width, append):
  sys.stdout.write('[{0}/{1}] - ['.format(val, pmax))
  sharps = int((float(val) / float(pmax)) * width)
  for i in range(0, sharps):
    sys.stdout.write('#')
  for i in range (sharps, width):
    sys.stdout.write(' ')
  percent = int((float(val) / float(pmax)) * 100)
  sys.stdout.write('] - {0}% - {1}'.format(percent, append))
  sys.stdout.flush()

def ok(message):
  print '\033[92m' + message + '\033[0m'

def error(message):
  print '\033[91m' + message + '\033[0m'

def warning(message):
  print '\033[93m' + message + '\033[0m'

def blue(message):
  print '\033[94m' + message + '\033[0m'

def purple(message):
  print '\033[95m' + message + '\033[0m'



#!/usr/bin/python
# -*- coding: utf-8 -*-
# 
import yaml
import os
import project
import dolly
import terminal
import sys

class Config:
	def __init__(self, path):
		self.data = self.__open(path)
		self.rootdir = dolly.Dolly.rootdir
	def __open(self, path):
		return yaml.load(open(path))

	def __normalizeTree(self, project):
		output = []
		for directory, repos in project.iteritems():
			for repository in repos:
				key = list(repository)[0]
				remote = repository[key]
				local = os.path.join(self.rootdir, directory, key)
				output.append({'local': local, 'remote': remote, 'name': key})
		return output

	def parse(self, name):
		if not (name in self.data):
			terminal.error("Project doesn't exist in config file")
			sys.exit(0)
		proj = self.data[name]
		tree = []
		includes = []
		description = ''
		post_update=None
		if 'tree' in proj:
			tree = self.__normalizeTree(proj['tree'])
		if 'includes' in proj:
			includes = proj['includes']
		if 'description' in proj:
			description = proj['description']
		if 'post_update' in proj:
			post_update = proj['post_update']

		return project.Project(name, description, tree, includes, self, post_update)




#!/usr/bin/python
# -*- coding: utf-8 -*-
# 
import os
import util
import project

class Update:
	def visit(self, host):
		for repo in host.tree:
			project.Project.currentProj += 1
			util.printStatus(repo)
			self.update(repo)

		if host.post_update:
			util.executeCommand(host.post_update)
	
	def update(self, repo):
		if os.path.exists(repo['local']):
			self.pull(repo)
		else:
			self.clone(repo)

	def clone(self, repo):
		if util.isGitRepo(repo):
			self.cloneGit(repo)
		else:
			self.cloneSvn(repo)

	def pull(self, repo):
		if util.isGitRepo(repo):
			self.pullGit(repo)
		else:
			self.pullSvn(repo)

	def cloneGit(self, repo):
		result = util.executeCommand('git clone {0} {1}'.format(repo['remote'], repo['local']))

	def cloneSvn(self, repo):
		result = util.executeCommand('svn checkout {0} {1}'.format(repo['remote'], repo['local']))

	def pullGit(self, repo):
		result = util.executeCommand('git pull --ff-only', cwd=repo['local'])

	def pullSvn(self, repo):
		result = util.executeCommand('svn update', cwd=repo['local'])


#!/usr/bin/python
# -*- coding: utf-8 -*-
# 
from setuptools import setup
setup(
	name = 'Dolly',
	packages = ['dolly'],
	version = '0.0.3',
	install_requires=['pyyaml', 'argparse'],
	entry_points={
		'console_scripts': [
			'dolly = dolly.dolly:main',
			'dly = dolly.dolly:main'
		]
	}
)